@@ -1,4 +1,5 @@
-from . import operators as op
+from giving import operators as op
+
 from .core import (
     BaseOverlay,
     Overlay,
@@ -7,7 +8,7 @@ from .core import (
     interact,
 )
 from .deco import PteraDecorator, tooled
-from .probe import LocalProbe, Probe, accumulate, probing
+from .probe import Probe, probing
 from .recur import Recurrence
 from .selector import select
 from .selfless import ConflictError, Override, default, override, transform
